pub enum GlyphNameOrder {
Monotonic,
MostlyMonotonicWithBackrefs,
AllPointToLast,
}Variants
Monotonic
Glyph name indices in strictly increasing order.
MostlyMonotonicWithBackrefs
Glyph name indices in mostly increasing order, with some back references to previous names.
This likely matches most sane font data with duplicate glyph names.
AllPointToLast
All glyph name indices point to the last glyph name.
This is the patholical case, requiring a full scan for each glyph during iteration.